/*
 *  file      : src/parse_data.c
 *  project   : b2im
 *  copyright : (C) 2015 by BULIN Claude
 * 
 *  This file is part of b2im project
 * 
 *  b2im is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; version 3.
 * 
 *  b2im is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif
#include <gtk/gtk.h>
#include <glib.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_b2im/lib.h"
#endif

#include "global.h"
#include "configuser.h"



typedef struct {
	gchar	**Larrbuf;
} PARSE_BUF;
PARSE_BUF	ParseBuf = { NULL };



// 
// 
void ParseData_close_conf_file( void )
{
	if( NULL != ParseBuf.Larrbuf ) {
		g_strfreev( ParseBuf.Larrbuf );
		ParseBuf.Larrbuf = NULL;
	}
}
// 
// 
gboolean ParseData_open_conf_file( gchar *p_PathNameConfig )
{
	size_t 		SizeFile;
	gchar		*Buffer = NULL;
	FILE		*fp = NULL;
	
	ParseData_close_conf_file();
	if(( SizeFile = libutils_get_size_file( p_PathNameConfig )) > 0 ) {
		if( NULL != ( fp = fopen( p_PathNameConfig, "r" ))) {
			Buffer = (gchar *)g_malloc0( sizeof(gchar) * ( SizeFile +10 ));
			SizeFile = fread( Buffer, SizeFile, 1, fp );
			fclose( fp );
			ParseBuf.Larrbuf = g_strsplit( Buffer, "\n", 0 );
			g_free( Buffer );
			Buffer = NULL;
			return( TRUE );
		}
	}
	return( FALSE );
}
// 
// 
gboolean ParseData_new_strcmp (gchar *p_src, gchar *p_dest)
{
	gint	len_aiguille = strlen (p_dest);
	gint	len_meule;
	gint	len;
	gchar	*PtrBeginSrc = NULL;
	gchar	*PtrEndSrc = NULL;
	gchar	*PtrSrc = NULL;
	gchar	*PtrDest = p_dest;
	
	for (PtrBeginSrc = p_src; *PtrBeginSrc == ' ' || *PtrBeginSrc == '\t'; PtrBeginSrc ++);
	for (PtrEndSrc = PtrBeginSrc; *PtrEndSrc != ' ' && *PtrEndSrc != '\t'; PtrEndSrc ++);
	len_meule = PtrEndSrc - PtrBeginSrc;
	
	if (len_meule != len_aiguille) return (FALSE);
	
	len = 0;
	for (PtrSrc = PtrBeginSrc; PtrSrc < PtrEndSrc; PtrSrc ++, PtrDest ++) {
		if (*PtrSrc != *PtrDest) return (FALSE);;
		len ++;
	}
	
	return (len_meule == len ? TRUE : FALSE);
}
// 
// 
gchar *ParseData_get_target( gchar *p_buf )
{
	gchar	*Str = NULL;
	gchar	*Ptr = NULL;
	
	if( NULL != ( Ptr = strchr( p_buf, '=' ))) {
		Ptr ++;
		while( *Ptr && (*Ptr != ' ' && *Ptr != '\t' )) Ptr ++;
		Ptr ++;
		Str = g_strdup( Ptr );
		if( NULL != ( Ptr = strchr( Str, '\r' ))) *Ptr = '\0';
		if( NULL != ( Ptr = strchr( Str, '\n' ))) *Ptr = '\0';
	}
	return( (gchar *)Str );
}
// 
// 
gchar *ParseData_get_str( gchar *p_Search )
{
	gchar	*Ptr = NULL;
	gint	Cpt;
	
	for( Cpt = 0; ParseBuf.Larrbuf[ Cpt ]; Cpt++ ) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if( *ParseBuf.Larrbuf[ Cpt ] == '#' || *ParseBuf.Larrbuf[ Cpt ] == '\0') continue;
		
		if( TRUE == ParseData_new_strcmp( ParseBuf.Larrbuf[ Cpt ], p_Search )) {
			if( NULL != ( Ptr = ParseData_get_target( ParseBuf.Larrbuf[ Cpt ]))) {
				return( (gchar *)Ptr );	
			}
		}
	}
	return( (gchar *)NULL );	
}
// 
// 
gchar *ParseData_read_value_str( gchar *p_Search, gchar **p_ValueStr )
{
	gchar	*Ptr = NULL;
	if( NULL != ( Ptr = ParseData_get_str( p_Search )))
		*p_ValueStr = g_strdup( Ptr );
	return( (gchar *)Ptr );
}
// 
// 
gint ParseData_read_value_atoi( gchar *p_Search, gint *p_ValueAtoi, gint p_Min, gint p_Max )
{
	gchar	*Ptr = NULL;
	gint	ret_value_int = -1;
	if( NULL != ( Ptr = ParseData_get_str( p_Search ))) {
		ret_value_int = atoi( Ptr );
		if( ret_value_int < p_Min ) ret_value_int = p_Min;
		if( ret_value_int > p_Max ) ret_value_int = p_Max;
	}
	return( ret_value_int );
}
